@@ -18,8 +18,10 @@ function (x, digits = max(options()$digits - 4, 3), ...)
 	  print(temp)
 	}
 	if (substr(x$information,2,3)!="Tr") {
-	  temp <- cbind(x$n, otmp, etmp, otmp - etmp, ((otmp - etmp)^2)/etmp,  ((otmp - etmp)^2)/diag(as.matrix(x$var)))
-	  dimnames(temp) <- list(names(x$n), c("N", "Observed", "Expected", "O-E", "(O-E)^2/E", "(O-E)^2/V"))
+	  temp <- cbind(x$n, otmp, etmp, otmp - etmp, ((otmp - etmp)^2)/etmp,
+                    ((otmp - etmp)^2)/diag(as.matrix(x$var)))
+	  dimnames(temp) <- list(names(x$n), c("N", "Observed", "Expected", "O-E",
+                                           "(O-E)^2/E", "(O-E)^2/V"))
 	  print(temp)
 	}
 	if (substr(x$information,2,2) == "K") {
